@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: approve.c,v 1.105 1999/02/18 20:31:01 will Exp $";
+static char rcsid[] = "$Id: approve.c,v 1.108 1999/05/09 18:55:02 will Exp $";
 
 /* The code should compile with either ANSI C or K&R compilers. */
 
@@ -633,21 +633,18 @@ char *usrcmd;
 {
     static char *usage[] = {
 "    %s command [args...]	\texecutes command [args]",
+"    %s                         \tlist ok cmds",
+"    %s [-H | -f] [MasqueradeOpts]\tlist ok cmds: -H=verbose,-f=just-facts",
 "    %s -h			\tprint this usage info, then exits",
 "    %s -V			\tprint version number, then exits",
-"    %s [-H | -f] [MasqueradeOptions]",
-"    				\tlist ok cmds: -H=verbose,-f=just-facts",
-"    %s [-d | -D] [MasqueradeOptions]  cmd [args...]",
-"    				\t...debug mode",
+"    %s [-d | -D] [MasqueradeOpts]\tcmd [args]\t...debug mode",
 "    %s -b			\tlists builtin variables, then exits",
 "    %s -c [superfile]	\tjust check syntax of the superfile",
 "",
 "Notes on options:",
-"    -d    ...basic debug mode: show what would be done,",
-"		but don't actually execute a command.",
-"    -D    ...same as -d, plus tell more about variables, plus other details.",
-"    -f -- (just the facts, ma'm) lists the commands you can execute, as:",
-"		    Cmd FullPath [initial args]",
+"    -d   Basic debug: show what would be done, but don't execute anything.",
+"    -D   Same as -d, plus tell more about variables, plus other details.",
+"    -f   (just the facts, ma'm): lists your cmds as: Cmd FullPath [args]",
 "	      Useful for scripts that want a list of what you may execute.",
 "MasqueradeOptions:",
 "    ** No command is ever executed when any MasqueradeOption is used.**",
