@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: checks.c,v 1.60 1999/02/26 08:36:44 will Exp $";
+static char rcsid[] = "$Id: checks.c,v 1.70 1999/06/15 08:05:54 will Exp $";
 /* The code should compile with either ANSI C or K&R compilers. */
 
 /*
@@ -465,8 +465,8 @@ get_encrypted_pw()
 	    return Error(1, 0,
 		"Failed to obtain shadow password entry for user %s: ",
 		userinfo.caller.pw_name);
-	userinfo.caller.pw_passwd = spwd->sp_pwdp;
-	strncpy(userinfo.salt, userinfo.caller.pw_passwd, 2);
+	strcpy(userinfo.encr, spwd->sp_pwdp);
+	strncpy(userinfo.salt, spwd->sp_pwdp, 2);
 	userinfo.salt[2] = '\0';
     } else {
 	strcpy(userinfo.encr, userinfo.caller.pw_passwd);
@@ -665,11 +665,12 @@ char *cmd, *user, *salt, *encr;
 	    strcpy(msg, "Password incorrect\nPassword: ");
 	}
 
-	encrypted = crypt(getpass( msg ), salt);
-	if (encr && encrypted)
+	encrypted = crypt(getpass(msg), salt);
+	if (encr && encrypted) {
 	    match = (strcmp(encr, encrypted) == 0);
-	else
+	} else {
 	    match = 0;
+	}
     }
     if (!match)
 	return Error(0, 0, "Password incorrect\n");
