@@ -19,5 +19,7 @@ typedef struct element {
 extern ENTRY   *hsearch();
 extern void     hdestroy();
 extern int      hcreate();
+extern void     hprint();
+extern void     htext();
 
 #endif
