@@ -166,6 +166,10 @@ gid_t getgid();
 #include <sys/security.h>
 #endif
 
+#ifdef HAVE_HPSECURITY_H
+#include <hpsecurity.h>
+#endif
+
 #ifdef HAVE_PROT_H
 #include <prot.h>
 #endif
