@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: options.c,v 1.80 1999/02/24 06:11:16 will Exp $";
+static char rcsid[] = "$Id: options.c,v 1.86 1999/05/05 17:24:04 will Exp $";
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* Process a global xxx=yyy option */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -13,7 +13,7 @@ static char rcsid[] = "$Id: options.c,v 1.80 1999/02/24 06:11:16 will Exp $";
 Option opts[] = {
 	{ "DIE",		LOCAL,		option_die },	/* OBSOLETE */
 	{ "addgroups",		LIST|GLOBAL|LOCAL,	option_groups },
-	{ "arg",		IS_ROOT|LOCAL,	option_arg },
+	{ "arg",		LOCAL,		option_arg },
 	{ "argv0",		LOCAL,		option_argv0 },
 	{ "cd",			GLOBAL|LOCAL,	option_cd },
 	{ "die",		LOCAL,		option_die },
@@ -90,30 +90,47 @@ Option *
 find_option(word)
 char *word;
 {
-    int i, l;
+    int i, wordlen, namelen;
     static int firsttime=1;
     Option *lower = &opts[0];
     Option *upper = &opts[NELEM(opts)-1];	/* 1 past last non-empty elt */
     Option *mid;
+    char *sep;
 
     if (firsttime) {
 	sort_optlist();
 	firsttime=0;
     }
-    
+
+    if ((strncmp(word, "arg", 3) == 0) && strchr("0123456789", word[3])) {
+	/* The argMMM[-NNN] option has to be treated as if it were "arg". */
+	word = "arg";
+	wordlen = 3;
+    } else if (!(sep = strchr(word, OPTION_SEP))) {
+	Error(0, 0,
+		"%t\n\tsuper.tab option `%s' is missing separator `%c'\n",
+		word, OPTION_SEP);
+	return NULL;
+    } else {
+	/* word length up to the separator */
+	wordlen = sep - word;
+    }
+
     while (lower < upper) {
 	mid = lower + (upper - lower) / 2;
-	l = strlen(mid->name);
-	if ((i=strncmp(word, mid->name, l)) < 0) {
+	namelen = strlen(mid->name);
+	if ((i=strncmp(word, mid->name, namelen)) < 0) {
 	    upper = mid;
 	} else if (i > 0) {
 	    lower = mid + 1;
-	} else if (mid->flags & IS_ROOT) {
-	    return mid;	/* Don't care if it's followed by <SEP> */
-	} else if (*(word+l) == OPTION_SEP) {
-	    return mid;	/* Must be followed by <SEP> */
+	} else if (wordlen == namelen) {
+	    /* exact match */
+	    return mid;
 	} else {
-	    /* It didn't compare right... word is longer, hence word > mid... */
+	    /* It didn't compare right.  If wordlen < namelen, the strncmp()
+	     * above would have failed, hence we know that wordlen > namelen,
+	     * hence hence word > mid...
+	     */
 	    lower = mid + 1;
 	}
     }
@@ -184,7 +201,7 @@ options cannot be negated: <%s>\n", word);
 			isglobal ? "global" : "local", word, value);
 	} else {
 	    return Error(0, 0,
-			"%t\n\tUnrecognized %s option `%s'.\n",
+			"%t\n\tInvalid %s option `%s'.\n",
 			isglobal ? "global" : "local", word);
 	}
     }
