@@ -7,10 +7,6 @@
 typedef int (*OptionFunc) P__((char *wd, char *s, int global));
 
 /* Flags for use in the options description */
-#define 	IS_ROOT		001 /* name is just leading part of xxx=yyy;
-				     * that is, name might be "xx" and entire
-				     * option name is xx0, xx1, ...
-				     */
 #define		GLOBAL		002 /* option is permitted as global opt */
 #define		LOCAL		004 /* option is permitted as local opt */
 #define		LIST		007 /* Run globbraces on argument, then
