@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: rsyslog.c,v 1.15 1998/03/02 06:53:59 will Exp $";
+static char rcsid[] = "$Id: rsyslog.c,v 1.16 1999/02/18 19:51:55 will Exp $";
 /*************************************************************************
 **
 ** Network version of syslog (syslog,openlog,closelog)
@@ -147,8 +147,11 @@ int facility;	/* same as in openlog() -- but don't rely on using #define'd
 		 * facilities than the machine running ropenlog(), and thus
 		 * may interpret this differently than you think.
 		 */
-char *host;	/* host is the name of the collecting machine */
+char *host;	/* host is the name of the collecting machine.
+		 * If a NULL pointer, gethostname() is used.
+		 */
 {
+    char nhost[500];
     struct hostent *pHost;
     struct servent *pService;
     char   msg[MAXLINE];
@@ -163,9 +166,11 @@ char *host;	/* host is the name of the collecting machine */
      * future possible core dumps)
      */
     if ( host==NULL ) {
-      perror("ropenlog(): host not defined (was passed NULL ptr!)");
-      errno = 0;
-      exit(-1);
+	if (gethostname(nhost, sizeof(nhost)) == -1) {
+	  perror("ropenlog(): host not defined and gethostname() failed:");
+	  exit(-1);
+	}
+	host = nhost;
     }
 
     /*
