@@ -104,10 +104,17 @@ int getdtablesize P__(( void ));
 /* maximum number of tries at entering the password */
 #define MAXTRY 3
 
-/* default maxlength per arg, maxlength all args */
+/* default maxlength per arg passed to a command, maxlength all args */
 #define MAXLEN1ARG 1000
 #define MAXLENARGS 10000
 
+/* define max length per option passed to super (not to the referenced
+ * command), the max total length, and the valid option pattern.
+ */
+#define MAXOPTLEN 250
+#define MAXOPTLEN_TOT 500
+#define OPT_PATTERN "^[-/:+.=%@!,_a-zA-Z0-9]*$"
+
 #ifdef HAVE_INNETGR
 extern int innetgr();
 #endif
@@ -155,6 +162,7 @@ void *memset P__(( void *s, int c, size_t n ));
     extern int check_syntax;		/* just check syntax of superfile */
     extern char *superfile;		/* The actual superfile to be opened. */
     extern int it_came_from_cmdline;	/* Set by -F/-T/-U/-G flags */
+    extern int using_user_supertab;	/* !0 means using a user's .supertab */
 
 /* The following external variables control the Error() routine.
  * They are modified at various points by super(), to give detailed control
@@ -163,6 +171,8 @@ void *memset P__(( void *s, int c, size_t n ));
     extern int error_stderr;		/* stderr() bool */
     extern int error_syslog;		/* syslog() bool */
     extern char *error_rlog_host;	/* where rsyslog() msgs are sent */
+    extern int error_priority;		/* syslog() "priority" */
+    extern int error_facility;		/* openlog() "facility" */
     extern char *error_command;		/* our program name */
     extern char *error_user;		/* our caller's username */
 
@@ -284,6 +294,7 @@ struct logInfo {
     pid_t pid;			/* PID of the logger; -1 means none running. */
     unsigned char newfile;	/* Bool: !0 if logfile given but not yet used */
     unsigned char newuid;	/* Bool: !0 if loguid given, but not yet used */
+    int syslog_success;		/* syslog() "priority" for success msgs */
 };
 typedef struct logInfo LogInfo;
 
@@ -372,8 +383,9 @@ struct userInfo {
 
     OurTime ourtime;			/* when we started, etc */
 
-    char encr[20];			/* encrypted password */
-    char salt[4];			/* salt from password */
+    char encr[256];			/* encrypted password; length is */
+					/* pretty large by current standards */
+    char salt[256];			/* salt from password */
 };
 typedef struct userInfo UserInfo;
 
@@ -413,8 +425,6 @@ struct localInfo {
     long maxlenargs;	/* max len of all args, combined */
     StrArray argpats;	/* argNNN=xxx arguments */
 
-    LogInfo log;	/* Information for logging to file */
-
     char mailcmd[500];	/* Information for logging via mail */
     int mail_success;	/* bool: mail on successful tries? (-1 = unknown) */
 
@@ -447,13 +457,16 @@ int	add_variable P__(( char *varname, char *vardefn ));
 void	anchor P__(( char *in, char *out ));
 char*	approve P__((char *usrcmd, int givehelp, int verbose));
 char ** blkdup P__((char **blk));
-int	blkfree P__((char **));
+int	blkfree P__((char **av0));
+char ** Blkdup P__((char *str, char **blk));
+int	Blkfree P__((char *str, char **av0));
 int	blkprint P__((char **));
 int	build_cmd_file P__((char *, int , char *, char **));
 char**	buttonup P__((char *));
 int	check_arglistlen P__(( char **argv ));
 int	check_owner P__(( void ));
 int	check_pass P__(( char *cmd ));
+int	check_value P__(( char *value, char *pat ));
 int	checkenv P__(( char *name,  char *value,  char *pat ));
 char*	clean_buf P__(( char *buf, char *outbuf ));
 void	close_writer P__(( void ));
@@ -552,4 +565,5 @@ int	StrNalloc P__(( StrArray *a, int nelt));
 int	StrNelts P__(( StrArray *a ));
 void	strtolower P__(( char *string ));
 char*	strqtokS P__(( char *, char *, char *, char *, unsigned int ));
+int	read_syslogcode P__(( char *str, int *code ));
 int	user_supertab P__(( char *command ));
