@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: utils.c,v 1.90 1998/04/14 17:06:49 will Exp $";
+static char rcsid[] = "$Id: utils.c,v 1.97 1999/02/24 05:16:21 will Exp $";
 #include "super.h"
 
 /* Variables table flag -- !0 means has been created */
@@ -78,6 +78,164 @@ char *buf;
     return 0;
 }
  
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/* Convert string to syslog priority code
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+int
+read_syslogcode(s, code)
+char *s;
+int *code;
+{
+    /*
+     * Takes a string like "LOG_AUTH | LOG_LOCAL1", and returns the
+     * corresponding syslog numeric value in *code.
+     * Returns:
+     *	0 on success;
+     *	-1 on error, with error message to Error().
+     *
+     * In s, the valid code separators are: whitespace and/or "|".
+     *
+     */
+    char *word;
+    char *sep = " \t|";
+
+    char *new_s;
+
+    if (!(new_s = strdup(s))) {
+	return Error(0, 0,
+	    "Failed to malloc space for copy of s=<%s>\n", s);
+    }
+
+    *code = 0;
+    for (word = strtok(new_s, sep); word; word = strtok(NULL, sep)) {
+	if (0) {
+	    /* placeholder */
+	/*
+	 * **********
+	 * Facilities
+	 * **********
+	 */
+#ifdef LOG_AUTH
+	} else if (strcmp(word, "LOG_AUTH") == 0) {
+	    *code |= LOG_AUTH;
+#endif
+#ifdef LOG_AUTHPRIV
+	} else if (strcmp(word, "LOG_AUTHPRIV") == 0) {
+	    *code |= LOG_AUTHPRIV;
+#endif
+#ifdef LOG_CRON
+	} else if (strcmp(word, "LOG_CRON") == 0) {
+	    *code |= LOG_CRON;
+#endif
+#ifdef LOG_DAEMON
+	} else if (strcmp(word, "LOG_DAEMON") == 0) {
+	    *code |= LOG_DAEMON;
+#endif
+#ifdef LOG_KERN
+	} else if (strcmp(word, "LOG_KERN") == 0) {
+	    *code |= LOG_KERN;
+#endif
+#ifdef LOG_LOCAL0
+	} else if (strcmp(word, "LOG_LOCAL0") == 0) {
+	    *code |= LOG_LOCAL0;
+#endif
+#ifdef LOG_LOCAL1
+	} else if (strcmp(word, "LOG_LOCAL1") == 0) {
+	    *code |= LOG_LOCAL1;
+#endif
+#ifdef LOG_LOCAL2
+	} else if (strcmp(word, "LOG_LOCAL2") == 0) {
+	    *code |= LOG_LOCAL2;
+#endif
+#ifdef LOG_LOCAL3
+	} else if (strcmp(word, "LOG_LOCAL3") == 0) {
+	    *code |= LOG_LOCAL3;
+#endif
+#ifdef LOG_LOCAL4
+	} else if (strcmp(word, "LOG_LOCAL4") == 0) {
+	    *code |= LOG_LOCAL4;
+#endif
+#ifdef LOG_LOCAL5
+	} else if (strcmp(word, "LOG_LOCAL5") == 0) {
+	    *code |= LOG_LOCAL5;
+#endif
+#ifdef LOG_LOCAL6
+	} else if (strcmp(word, "LOG_LOCAL6") == 0) {
+	    *code |= LOG_LOCAL6;
+#endif
+#ifdef LOG_LOCAL7
+	} else if (strcmp(word, "LOG_LOCAL7") == 0) {
+	    *code |= LOG_LOCAL7;
+#endif
+#ifdef LOG_LPR
+	} else if (strcmp(word, "LOG_LPR") == 0) {
+	    *code |= LOG_LPR;
+#endif
+#ifdef LOG_MAIL
+	} else if (strcmp(word, "LOG_MAIL") == 0) {
+	    *code |= LOG_MAIL;
+#endif
+#ifdef LOG_NEWS
+	} else if (strcmp(word, "LOG_NEWS") == 0) {
+	    *code |= LOG_NEWS;
+#endif
+#ifdef LOG_RFS
+	} else if (strcmp(word, "LOG_NEWS") == 0) {
+	    *code |= LOG_RFS;
+#endif
+#ifdef LOG_USER
+	} else if (strcmp(word, "LOG_USER") == 0) {
+	    *code |= LOG_USER;
+#endif
+#ifdef LOG_UUCP
+	} else if (strcmp(word, "LOG_UUCP") == 0) {
+	    *code |= LOG_UUCP;
+#endif
+	/*
+	 * ******
+	 * Levels
+	 * ******
+	 */
+#ifdef LOG_ALERT
+	} else if (strcmp(word, "LOG_ALERT") == 0) {
+	    *code |= LOG_ALERT;
+#endif
+#ifdef LOG_CRIT
+	} else if (strcmp(word, "LOG_CRIT") == 0) {
+	    *code |= LOG_CRIT;
+#endif
+#ifdef LOG_DEBUG
+	} else if (strcmp(word, "LOG_DEBUG") == 0) {
+	    *code |= LOG_DEBUG;
+#endif
+#ifdef LOG_EMERG
+	} else if (strcmp(word, "LOG_EMERG") == 0) {
+	    *code |= LOG_EMERG;
+#endif
+#ifdef LOG_ERR
+	} else if (strcmp(word, "LOG_ERR") == 0) {
+	    *code |= LOG_ERR;
+#endif
+#ifdef LOG_INFO
+	} else if (strcmp(word, "LOG_INFO") == 0) {
+	    *code |= LOG_INFO;
+#endif
+#ifdef LOG_NOTICE
+	} else if (strcmp(word, "LOG_NOTICE") == 0) {
+	    *code |= LOG_NOTICE;
+#endif
+#ifdef LOG_WARNING
+	} else if (strcmp(word, "LOG_WARNING") == 0) {
+	    *code |= LOG_WARNING;
+#endif
+	} else {
+	    free(new_s);
+	    return Error(0, 0, "%t\n\tUnknown syslog code <%s>\n", word);
+	}
+    }
+    free(new_s);
+    return 0;
+}
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* Copies in to out, prefixing with "^" and suffixing with "$"
  * if these are missing.
@@ -677,6 +835,12 @@ opensuperlog()
 
     close_writer();		/* in case there is already one running */
 
+    if (debug || it_came_from_cmdline) {
+	Error(0, 0,
+	  "If this weren't debug mode, \
+super would try to open as log file \"%.500s\"\n", globalinfo.log.filename);
+	return;
+    }
     if (*globalinfo.log.filename == '\0') {
 	Error(0, 0, "opensuperlog(): logfile name is (nil)\n");
 	return;
@@ -1507,6 +1671,9 @@ strdup(s)
 char *s;
 {
     char *t = (char *) malloc(strlen(s)+1);
+    if (!t) {
+	return NULL;
+    }
     strcpy(t, s);
     return t;
 }
@@ -1544,3 +1711,31 @@ ERROR -- YOU HAVE NEITHER v?printf() NOR _doprnt().
 YOU ARE HOSED UNTIL YOU SUPPLY ONE OF THESE.
 #endif
 #endif
+
+/***********************************************************************/
+
+/*
+ * my_alloc, my_realloc, my_free can be handy to add debugging info to,
+ * when allocation errors are happening.
+ */
+void *
+my_malloc(size_t size)
+{
+    void *p = malloc(size);
+    printf("my_malloc(%d) -> %p\n", size, p);
+    return p;
+}
+void *
+my_realloc(void *ptr, size_t size)
+{
+    void *p = realloc(ptr, size);
+    printf("my_realloc(%p, %d) -> %p\n", ptr, size, p);
+    return p;
+}
+void
+my_free(void *ptr)
+{
+    printf("my_free(%p)\n", ptr);
+    free(ptr);
+    return;
+}
